@@ -18,6 +18,16 @@ def xmlrpc_to_bugzilla_errors(func):
             return func(*args, **kwargs)
         except xmlrpclib.Fault as e:
             raise BugzillaError(e.faultString, e.faultCode)
+        except xmlrpclib.ProtocolError as e:
+            raise BugzillaError(e.errmsg, e.errcode)
+        except IOError as e:
+            # Raised when the protocol is invalid.
+            msg = 'unknown IOError'
+
+            if e.args:
+                msg = e.args[0]
+
+            raise BugzillaError(msg)
     return _transform_errors
 
 
@@ -74,9 +84,16 @@ class Bugzilla(object):
 
             user_id = result['id']
 
-        params = {'ids': [user_id], 'include_fields': self.user_fields}
+        params = {'ids': [user_id], 'include_fields': self.user_fields,
+                  'groups': ['reviewboard']}
 
-        return self.proxy.User.get(params)
+        try:
+            return self.proxy.User.get(params)
+        except xmlrpclib.Fault as e:
+            if e.faultCode == 804:
+                # User isn't a member of the requisite group.
+                return None
+            raise
 
     @xmlrpc_to_bugzilla_errors
     def get_user(self, username):
@@ -110,7 +127,7 @@ class Bugzilla(object):
         return bool(groups)
 
     @xmlrpc_to_bugzilla_errors
-    def post_rb_url(self, bug_id, review_id, summary, description, url,
+    def post_rb_url(self, bug_id, review_id, summary, comment, url,
                     reviewers):
         """Posts a new attachment containing a review-request URL, or updates
            an existing one."""
@@ -163,7 +180,7 @@ class Bugzilla(object):
 
         params['file_name'] = 'reviewboard-%d-url.txt' % review_id
         params['summary'] = summary
-        params['comment'] = description
+        params['comment'] = comment
         if flags:
             params['flags'] = flags
 
